summaryrefslogtreecommitdiff
path: root/lib/x509/x509.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/x509/x509.c')
-rw-r--r--lib/x509/x509.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/x509/x509.c b/lib/x509/x509.c
index 1c6206af61..067dab13be 100644
--- a/lib/x509/x509.c
+++ b/lib/x509/x509.c
@@ -2305,7 +2305,7 @@ gnutls_x509_crt_check_revocation (gnutls_x509_crt_t cert,
}
/**
* gnutls_x509_crt_get_sig_algorithm - This function will return the hash algorithm used during signature.
* @hash: The result of the call with the hash algorithm used for signature
* @crt: Holds the certificate
* @signature: contains the signature
@@ -2317,7 +2317,7 @@ gnutls_x509_crt_check_revocation (gnutls_x509_crt_t cert,
* returned on error.
**/
int
-gnutls_x509_crt_get_sig_algorithm(gnutls_digest_algorithm_t *hash,
+gnutls_x509_crt_get_verify_algorithm(gnutls_digest_algorithm_t *hash,
const gnutls_x509_crt_t crt,
const gnutls_datum_t * signature)
{
@@ -2327,7 +2327,7 @@ gnutls_x509_crt_get_sig_algorithm(gnutls_digest_algorithm_t *hash,
return GNUTLS_E_INVALID_REQUEST;
}
- return _gnutls_x509_verify_algorithm(hash, signature, crt);
+ return _gnutls_x509_verify_algorithm((gnutls_mac_algorithm_t*)hash, signature, crt);
}
/**
@@ -2305,7 +2305,7 @@ gnutls_x509_crt_check_revocation (gnutls_x509_crt_t cert,
}
/**
- * gnutls_x509_crt_get_sig_algorithm - This function will return the hash algorithm used during signature.
+ * gnutls_x509_crt_get_verify_algorithm - This function will return the hash algorithm used during signature.
* @hash: The result of the call with the hash algorithm used for signature
* @crt: Holds the certificate